@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2009-2022 -- leonerd@leonerd.org.uk
 
-package Convert::Color::RGB16 0.16;
+package Convert::Color::RGB16 0.18;
 
 use v5.14;
 use warnings;
@@ -54,12 +54,12 @@ For representations using 8-bit integers, see L<Convert::Color::RGB8>.
 
 =head2 new
 
-   $color = Convert::Color::RGB16->new( $red, $green, $blue )
+   $color = Convert::Color::RGB16->new( $red, $green, $blue );
 
 Returns a new object to represent the set of values given. These values should
 be integers between 0 and 65535. Values outside of this range will be clamped.
 
-   $color = Convert::Color::RGB16->new( $string )
+   $color = Convert::Color::RGB16->new( $string );
 
 Parses C<$string> for values, and construct a new object similar to the above
 three-argument form. The string should be in the form
@@ -114,15 +114,15 @@ sub new
 
 =head2 red
 
-   $r = $color->red
+   $r = $color->red;
 
 =head2 green
 
-   $g = $color->green
+   $g = $color->green;
 
 =head2 blue
 
-   $b = $color->blue
+   $b = $color->blue;
 
 Accessors for the three components of the color.
 
@@ -150,7 +150,7 @@ sub new_rgb
 
 =head2 rgb16
 
-   ( $red, $green, $blue ) = $color->rgb16
+   ( $red, $green, $blue ) = $color->rgb16;
 
 Returns the individual red, green and blue color components of the color
 value in RGB16 space.
@@ -165,7 +165,7 @@ sub rgb16
 
 =head2 hex
 
-   $str = $color->hex
+   $str = $color->hex;
 
 Returns a string representation of the color components in the RGB16 space, in
 a convenient C<RRRRGGGGBBBB> hex string.
@@ -180,7 +180,7 @@ sub hex :method
 
 =head2 alpha_blend
 
-   $mix = $color->alpha_blend( $other, [ $alpha ] )
+   $mix = $color->alpha_blend( $other, [ $alpha ] );
 
 Return a new color which is a blended combination of the two passed into it.
 The optional C<$alpha> parameter defines the mix ratio between the two colors,
@@ -214,7 +214,7 @@ sub alpha_blend
 
 =head2 alpha16_blend
 
-   $mix = $color->alpha16_blend( $other, [ $alpha ] )
+   $mix = $color->alpha16_blend( $other, [ $alpha ] );
 
 Similar to C<alpha_blend> but works with integer arithmetic. C<$alpha> should
 be an integer in the range 0 to 65535.
@@ -246,7 +246,7 @@ sub alpha16_blend
 
 =head2 dst_rgb16
 
-   $measure = $color->dst_rgb16( $other )
+   $measure = $color->dst_rgb16( $other );
 
 Return a measure of the distance between the two colors. This is the
 unweighted Euclidean distance of the three color components. Two identical
@@ -265,7 +265,7 @@ sub dst_rgb16
 
 =head2 dst_rgb16_cheap
 
-   $measure = $color->dst_rgb16_cheap( $other )
+   $measure = $color->dst_rgb16_cheap( $other );
 
 Return a measure of the distance between the two colors. This is the sum of
 the squares of the differences of each of the color components. This is part
